@@ -30,35 +30,35 @@ DocExample::~DocExample()
 {
 }
 
-bool DocExample::load()
+bool DocExample::load_after()
 {
-  bool bTest = Bakery::Document::load();
+  bool bTest = Bakery::Document::load_after();
 
   if(bTest)
   {
-	  //See comment in save().
+	  //See comment in save_before().
 	  m_strSomething = get_contents();
   } 
 
   return bTest; 
 }
 
-bool DocExample::save()
+bool DocExample::save_before()
 {
   //You would ususally save your many pieces of data in some kind of file format,
   //e.g. XML.
   set_contents(m_strSomething);
-  return Bakery::Document::save();  
+  return Bakery::Document::save_before();
 }
 
-void DocExample::set_something(const std::string& strSomething)
+void DocExample::set_something(const Glib::ustring& strSomething)
 {
   m_strSomething = strSomething;
 
   set_modified();
 }
 
-std::string DocExample::get_something() const
+Glib::ustring DocExample::get_something() const
 {
   return m_strSomething;
 }
