@@ -19,15 +19,17 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include <libintl.h>
+
 #include "appexample.h"
 
 AppExample::AppExample()
-  : Bakery::App("WithoutDoc", "WithoutDoc"),
+  : Bakery::App_Gtk("WithoutDoc"),
   m_Label("blah")
 {
- m_Box.pack_start(m_Label, false);
- m_Box.pack_start(m_Entry, false);
- m_Box.show_all();
+  m_Box.pack_start(m_Label, Gtk::PACK_EXPAND_WIDGET);
+  m_Box.pack_start(m_Entry, Gtk::PACK_EXPAND_WIDGET);
+  m_Box.show_all();
 }
 
 AppExample::~AppExample()
@@ -38,19 +40,17 @@ void AppExample::init()
 {
   type_vecStrings vecAuthors;
   vecAuthors.push_back("Murray Cumming <murrayc@usa.net>");
-  set_about_information("0.1", vecAuthors, _("(C) 2000 Murray Cumming"), _("A Bakery example"));
+  set_about_information("0.1", vecAuthors, gettext("(C) 2000 Murray Cumming"), gettext("A Bakery example"));
 
   //Call base method:
-  Bakery::App::init();
+  Bakery::App_Gtk::init();
 
-  set_contents(m_Box);
+  add(m_Box);
 }
 
 Bakery::App* AppExample::new_instance()
 {
-  //The manage() is necessary, but I'm not sure why.
-  //Without it, the destroy() on the last instance doesn't call the destructor.
-  AppExample* pApp = Gtk::manage(new AppExample());
+  AppExample* pApp = new AppExample();
   return pApp;
 }
 
